@@ -47,7 +47,7 @@ private Q_SLOTS:
     {
         auto data = QByteArray::fromHex("00f569d018f111d017d43b7d68003b8268008532da110000030000000002000992000000000000db0c000000000000000000000000dc0f1117d40000000004b000000000000018f110007a18f13b7974cfd400000017d48a00000105d601000105d602474200000000005644561400");
 
-        VdvTicket ticket(data);
+        VdvTicket ticket(data, {});
         QCOMPARE(ticket.issuerId(), 6385);
         QCOMPARE(ticket.beginDateTime(), QDateTime({2019, 11, 29}, {13, 0}));
         QCOMPARE(ticket.endDateTime(), QDateTime({2019, 12, 2}, {13, 0}));
@@ -56,7 +56,7 @@ private Q_SLOTS:
         QCOMPARE(ticket.ticketNumber(), QStringLiteral("16083408"));
 
         data = QByteArray::fromHex("001a4bab1874283e184434ba000134bb18008541da110001000000000003000000000000001a4bdb1502199610144B6174696523447261676F6E00000000dc150000000000000000000000000000000000000000001874110064187434b87128ff7a126918748a0000062e9e0100062e9e007d895644561107");
-        ticket = VdvTicket(data);
+        ticket = VdvTicket(data, {});
         QCOMPARE(ticket.issuerId(), 6260);
         QCOMPARE(ticket.beginDateTime(), QDateTime({2016, 5, 26}, {0, 0, 2}));
         QCOMPARE(ticket.endDateTime(), QDateTime({2016, 5, 27}, {3, 0}));
@@ -66,7 +66,7 @@ private Q_SLOTS:
         QCOMPARE(ticket.ticketNumber(), QStringLiteral("1723307"));
 
         data = QByteArray::fromHex("00f569d018f111d017d43b7d68003b8268008532da110000030000000000000992000000000000db0c00000000004B33654044346Edc0f1117d40000000004b000000000000018f110007a18f13b7974cfd400000017d48a00000105d601000105d602474200000000005644561400");
-        ticket = VdvTicket(data);
+        ticket = VdvTicket(data, {});
         QCOMPARE(ticket.serviceClass(), VdvTicket::UnknownClass);
         QCOMPARE(ticket.person().familyName(), QStringLiteral("D"));
         QCOMPARE(ticket.person().givenName(), QStringLiteral("K"));
